aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/cal-util
diff options
context:
space:
mode:
Diffstat (limited to 'calendar/cal-util')
-rw-r--r--calendar/cal-util/cal-component.c60
-rw-r--r--calendar/cal-util/cal-component.h22
-rw-r--r--calendar/cal-util/cal-recur.c34
-rw-r--r--calendar/cal-util/cal-util.c30
-rw-r--r--calendar/cal-util/cal-util.h7
5 files changed, 47 insertions, 106 deletions
diff --git a/calendar/cal-util/cal-component.h b/calendar/cal-util/cal-component.h
index f363099836..3117dcdf2e 100644
--- a/calendar/cal-util/cal-component.h
+++ b/calendar/cal-util/cal-component.h
@@ -22,21 +22,21 @@
#ifndef CAL_COMPONENT_H
#define CAL_COMPONENT_H
-#include <glib/gmacros.h>
+#include <libgnome/gnome-defs.h>
#include <time.h>
-#include <glib-object.h>
+#include <gtk/gtkobject.h>
#include <ical.h>
-G_BEGIN_DECLS
+BEGIN_GNOME_DECLS
#define CAL_COMPONENT_TYPE (cal_component_get_type ())
-#define CAL_COMPONENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CAL_COMPONENT_TYPE, CalComponent))
-#define CAL_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CAL_COMPONENT_TYPE, \
+#define CAL_COMPONENT(obj) (GTK_CHECK_CAST ((obj), CAL_COMPONENT_TYPE, CalComponent))
+#define CAL_COMPONENT_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass), CAL_COMPONENT_TYPE, \
CalComponentClass))
-#define IS_CAL_COMPONENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CAL_COMPONENT_TYPE))
-#define IS_CAL_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CAL_COMPONENT_TYPE))
+#define IS_CAL_COMPONENT(obj) (GTK_CHECK_TYPE ((obj), CAL_COMPONENT_TYPE))
+#define IS_CAL_COMPONENT_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), CAL_COMPONENT_TYPE))
/* Types of calendar components to be stored by a CalComponent, as per RFC 2445.
* We don't put the alarm component type here since we store alarms as separate
@@ -184,19 +184,19 @@ typedef struct _CalComponentClass CalComponentClass;
typedef struct _CalComponentPrivate CalComponentPrivate;
struct _CalComponent {
- GObject object;
+ GtkObject object;
/* Private data */
CalComponentPrivate *priv;
};
struct _CalComponentClass {
- GObjectClass parent_class;
+ GtkObjectClass parent_class;
};
/* Calendar component */
-GType cal_component_get_type (void);
+GtkType cal_component_get_type (void);
char *cal_component_gen_uid (void);
@@ -444,6 +444,6 @@ icalcomponent *cal_component_alarm_get_icalcomponent (CalComponentAlarm *alarm);
-G_END_DECLS
+END_GNOME_DECLS
#endif
diff --git a/calendar/cal-util/cal-recur.c b/calendar/cal-util/cal-recur.c
index 123198676c..8ba1fc435d 100644
--- a/calendar/cal-util/cal-recur.c
+++ b/calendar/cal-util/cal-recur.c
@@ -23,7 +23,6 @@
#include <config.h>
#include <stdlib.h>
#include <string.h>
-#include <libgnome/gnome-i18n.h>
#include <cal-util/cal-recur.h>
#include <cal-util/timeutil.h>
@@ -3981,36 +3980,3 @@ cal_recur_set_rule_end_date (icalproperty *prop,
icalproperty_add_parameter (prop, param);
}
-const char *cal_recur_nth[31] = {
- N_("1st"),
- N_("2nd"),
- N_("3rd"),
- N_("4th"),
- N_("5th"),
- N_("6th"),
- N_("7th"),
- N_("8th"),
- N_("9th"),
- N_("10th"),
- N_("11th"),
- N_("12th"),
- N_("13th"),
- N_("14th"),
- N_("15th"),
- N_("16th"),
- N_("17th"),
- N_("18th"),
- N_("19th"),
- N_("20th"),
- N_("21st"),
- N_("22nd"),
- N_("23rd"),
- N_("24th"),
- N_("25th"),
- N_("26th"),
- N_("27th"),
- N_("28th"),
- N_("29th"),
- N_("30th"),
- N_("31st")
-};
diff --git a/calendar/cal-util/cal-util.c b/calendar/cal-util/cal-util.c
index ad495bca77..bb89c043b4 100644
--- a/calendar/cal-util/cal-util.c
+++ b/calendar/cal-util/cal-util.c
@@ -23,6 +23,7 @@
#include <stdlib.h>
#include <string.h>
#include <glib.h>
+#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>
#include <libgnome/gnome-util.h>
#include "cal-util.h"
@@ -102,33 +103,6 @@ cal_util_new_top_level (void)
return icalcomp;
}
-static char *
-get_line_fn (char *buf, size_t size, void *file)
-{
- return fgets (buf, size, file);
-}
-
-icalcomponent *
-cal_util_parse_ics_file (const char *filename)
-{
- icalparser *parser;
- icalcomponent *icalcomp;
- FILE *file;
-
- file = fopen (filename, "r");
- if (!file)
- return NULL;
-
- parser = icalparser_new ();
- icalparser_set_gen_data (parser, file);
-
- icalcomp = icalparser_parse (parser, get_line_fn);
- icalparser_free (parser);
- fclose (file);
-
- return icalcomp;
-}
-
/* Computes the range of time in which recurrences should be generated for a
* component in order to compute alarm trigger times.
*/
@@ -483,7 +457,7 @@ cal_util_generate_alarms_for_comp (CalComponent *comp,
alarms = g_new (CalComponentAlarms, 1);
alarms->comp = comp;
- g_object_ref (G_OBJECT (alarms->comp));
+ gtk_object_ref (GTK_OBJECT (alarms->comp));
alarms->alarms = g_slist_sort (aod.triggers, compare_alarm_instance);
return alarms;
diff --git a/calendar/cal-util/cal-util.h b/calendar/cal-util/cal-util.h
index 7b4f6c051e..e48fb2b80e 100644
--- a/calendar/cal-util/cal-util.h
+++ b/calendar/cal-util/cal-util.h
@@ -22,13 +22,14 @@
#ifndef CAL_UTIL_H
#define CAL_UTIL_H
+#include <libgnome/gnome-defs.h>
#include <ical.h>
#include <time.h>
#include <glib.h>
#include <cal-util/cal-component.h>
#include <cal-util/cal-recur.h>
-G_BEGIN_DECLS
+BEGIN_GNOME_DECLS
@@ -71,8 +72,6 @@ void cal_obj_uid_list_free (GList *list);
icalcomponent *cal_util_new_top_level (void);
-icalcomponent *cal_util_parse_ics_file (const char *filename);
-
CalComponentAlarms *cal_util_generate_alarms_for_comp (CalComponent *comp,
time_t start,
time_t end,
@@ -99,7 +98,7 @@ char *cal_util_expand_uri (char *uri, gboolean tasks);
void cal_util_add_timezones_from_component (icalcomponent *vcal_comp,
CalComponent *comp);
-G_END_DECLS
+END_GNOME_DECLS
#endif
diff --git a/calendar/cal-util/cal-component.c b/calendar/cal-util/cal-component.c
index 671af4a9ec..2c9fce2f85 100644
--- a/calendar/cal-util/cal-component.c
+++ b/calendar/cal-util/cal-component.c
@@ -24,6 +24,7 @@
#include <stdlib.h>
#include <unistd.h>
#include <glib.h>
+#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>
#include "cal-component.h"
#include "timeutil.h"
@@ -180,11 +181,11 @@ struct _CalComponentAlarm {
-static void cal_component_class_init (CalComponentClass *klass);
-static void cal_component_init (CalComponent *comp, CalComponentClass *klass);
-static void cal_component_finalize (GObject *object);
+static void cal_component_class_init (CalComponentClass *class);
+static void cal_component_init (CalComponent *comp);
+static void cal_component_destroy (GtkObject *object);
-static GObjectClass *parent_class;
+static GtkObjectClass *parent_class;
@@ -196,23 +197,24 @@ static GObjectClass *parent_class;
*
* Return value: The type ID of the #CalComponent class.
**/
-GType
+GtkType
cal_component_get_type (void)
{
- static GType cal_component_type = 0;
+ static GtkType cal_component_type = 0;
if (!cal_component_type) {
- static GTypeInfo info = {
- sizeof (CalComponentClass),
- (GBaseInitFunc) NULL,
- (GBaseFinalizeFunc) NULL,
- (GClassInitFunc) cal_component_class_init,
- NULL, NULL,
- sizeof (CalComponent),
- 0,
- (GInstanceInitFunc) cal_component_init
- };
- cal_component_type = g_type_register_static (G_TYPE_OBJECT, "CalComponent", &info, 0);
+ static const GtkTypeInfo cal_component_info = {
+ "CalComponent",
+ sizeof (CalComponent),
+ sizeof (CalComponentClass),
+ (GtkClassInitFunc) cal_component_class_init,
+ (GtkObjectInitFunc) cal_component_init,
+ NULL, /* reserved_1 */
+ NULL, /* reserved_2 */
+ (GtkClassInitFunc) NULL
+ };
+
+ cal_component_type = gtk_type_unique (GTK_TYPE_OBJECT, &cal_component_info);
}
return cal_component_type;
@@ -220,20 +222,20 @@ cal_component_get_type (void)
/* Class initialization function for the calendar component object */
static void
-cal_component_class_init (CalComponentClass *klass)
+cal_component_class_init (CalComponentClass *class)
{
- GObjectClass *object_class;
+ GtkObjectClass *object_class;
- object_class = (GObjectClass *) klass;
+ object_class = (GtkObjectClass *) class;
- parent_class = g_type_class_peek_parent (klass);
+ parent_class = gtk_type_class (GTK_TYPE_OBJECT);
- object_class->finalize = cal_component_finalize;
+ object_class->destroy = cal_component_destroy;
}
/* Object initialization function for the calendar component object */
static void
-cal_component_init (CalComponent *comp, CalComponentClass *klass)
+cal_component_init (CalComponent *comp)
{
CalComponentPrivate *priv;
@@ -356,9 +358,9 @@ free_icalcomponent (CalComponent *comp, gboolean free)
priv->need_sequence_inc = FALSE;
}
/* Finalize handler for the calendar component object */
static void
-cal_component_finalize (GObject *object)
+cal_component_destroy (GtkObject *object)
{
CalComponent *comp;
CalComponentPrivate *priv;
@@ -376,8 +378,8 @@ cal_component_finalize (GObject *object)
g_free (priv);
comp->priv = NULL;
- if (G_OBJECT_CLASS (parent_class)->finalize)
- (* G_OBJECT_CLASS (parent_class)->finalize) (object);
+ if (GTK_OBJECT_CLASS (parent_class)->destroy)
+ (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
}
@@ -433,7 +435,7 @@ cal_component_gen_uid (void)
CalComponent *
cal_component_new (void)
{
- return CAL_COMPONENT (g_object_new (CAL_COMPONENT_TYPE, NULL));
+ return CAL_COMPONENT (gtk_type_new (CAL_COMPONENT_TYPE));
}
/**
@@ -4785,7 +4787,7 @@ cal_component_alarms_free (CalComponentAlarms *alarms)
g_return_if_fail (alarms != NULL);
g_assert (alarms->comp != NULL);
- g_object_unref (G_OBJECT (alarms->comp));
+ gtk_object_unref (GTK_OBJECT (alarms->comp));
for (l = alarms->alarms; l; l = l->next) {
CalAlarmInstance *instance;
@@ -356,9 +358,9 @@ free_icalcomponent (CalComponent *comp, gboolean free)
priv->need_sequence_inc = FALSE;
}
-/* Finalize handler for the calendar component object */
+/* Destroy handler for the calendar component object */
static void